rad.both <-
function(ref=NULL, data=TRUE, labels=TRUE, ...)

Read(ref, data=TRUE, labels=TRUE, ...)
